package Pcore::Util::URI::file;    ## no critic qw[NamingConventions::Capitalization]

use Pcore -class;

extends qw[Pcore::Util::URI];

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::Util::URI::file

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 ATTRIBUTES

=head1 METHODS

=head1 SEE ALSO

=cut
